/* 
   Main file
   --------------------------------------------------------------------
   Linberto

   Copyright (C) 1999-2001 Diego Javier Grigna <diego@grigna.com>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "common.h"

static void main_loop( void);
static void main_do_screen( void);

int main( int argc, char *argv[])
{
 nls_init();
 init_svgalib();
 init_signals();

 palette_init();

 main_loop();

 return 0;
}

static void main_loop( void)
{
 int pos = 0;

 sound_music( SND_WELCOME);

 while( 1) {
        main_do_screen();

        pos = menu( 100, 142, 112, pos, 4, 4);

        switch( pos) {
                /* Start Game */
                case 0: game_loop();
                        sound_music( SND_WELCOME);
                        break;
                /* Show Instructions */
                case 1: help_show_instructions();
                        break;
                /* View High Scores */
                case 2: score_show();
                        break;
                /* Change the setup */
                case 3: setup();
                        sound_music( SND_WELCOME);
                        break;
                /* Exit */
                case 4: exit_game( 0);
                        break;
        }

 } /* end while( 1) */

}

static void main_do_screen( void)
{
 struct timeval random_seed;
 int color_ndx;
 int x, y;
 int i;
 int skip_anim;

 gettimeofday( &random_seed, ( struct timezone *) NULL);
 srand( (unsigned int) random_seed.tv_usec);

 gl_clearscreen( 0);

 y = 144;

 screen_center_text( _("Start Game")  , y     );
 screen_center_text( _("Instructions"), y + 10);
 screen_center_text( _("Highscores")  , y + 20);
 screen_center_text( _("Setup")       , y + 30);
 screen_center_text( _("Exit")        , y + 40);

 skip_anim = 0;
 for( i = 0; i < 800 && !skip_anim; i++) {
      color_ndx = 1 + ( int) (4.0 * rand() / ( RAND_MAX + 1.0));
      x = 15 + ( int) ( 290.0 * rand() / ( RAND_MAX + 15.0));
      y =  4 + ( int) (  20.0 * rand() / ( RAND_MAX + 10.0));
      draw_mini_cube( x, y, lcolors[ color_ndx]);
      color_ndx = 1 + ( int) (4.0 * rand() / ( RAND_MAX + 1.0));
      x =  15 + ( int) ( 290.0 * rand() / ( RAND_MAX + 15.0));
      y = 100 + ( int) (  20.0 * rand() / ( RAND_MAX + 10.0));
      draw_mini_cube( x, y, lcolors[ color_ndx]);
      if( keyboard_update() == 0 && joy_button_any() == 0)
          continue;
      switch( lin_scancode) {
              case SCANCODE_ESCAPE:
              case SCANCODE_SPACE :
              case SCANCODE_ENTER : skip_anim = 1;
                                    break;
      }
 }

 gl_putboxmask( 39, 45, 241, 45, title);
}

